@@ -23,8 +23,8 @@ class NWP(DataSourceOutput):
 
         v.check_nan_and_inf(data=v.data)
 
-        v.check_data_var_dim(
-            v.data, ("example", "time_index", "x_osgb_index", "y_osgb_index", "channels_index")
-        )
+        dims = ("example", "time_index", "x_osgb_index", "y_osgb_index", "channels_index")
+        v.check_data_var_dim(v.data, dims)
+        v = v.order_dims(v, variable="data", expected_dims=dims)
 
         return v
